@@ -16,6 +16,7 @@
 
 package org.debian.maven.plugin;
 
+import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileReader;
 import java.io.IOException;
@@ -27,6 +28,8 @@ import java.util.regex.Pattern;
 import org.apache.maven.plugin.AbstractMojo;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.codehaus.plexus.util.FileUtils;
+import org.codehaus.plexus.util.io.RawInputStreamFacade;
+import org.debian.maven.repo.Dependency;
 import org.debian.maven.repo.ListOfPOMs;
 import org.debian.maven.repo.POMCleaner;
 import org.debian.maven.repo.POMOptions;
@@ -197,6 +200,10 @@ public class SysInstallMojo extends AbstractMojo {
 
     private String classifier;
 
+    /**
+     * The Maven artifacts relocated to this artifact.
+     */
+    private List<Dependency> relocatedArtifacts;
 
     // ----------------------------------------------------------------------
     // Public methods
@@ -394,21 +401,28 @@ public class SysInstallMojo extends AbstractMojo {
      * returns e.g. /org/debian/maven/debian-maven-plugin/0.1/
      */
     protected final String repoPath() {
-        return "/" + groupId.replace('.', '/') + "/" + artifactId + "/" + version + "/";
+        return artifactPath(groupId, artifactId, version);
     }
 
     /**
      * returns e.g. /org/debian/maven/debian-maven-plugin/0.1/
      */
     protected final String destRepoPath() {
-        return "/" + destGroupId.replace('.', '/') + "/" + destArtifactId + "/" + version + "/";
+        return artifactPath(destGroupId, destArtifactId, version);
     }
 
     /**
      * returns e.g. /org/debian/maven/debian-maven-plugin/debian/
      */
     protected final String debianRepoPath() {
-        return "/" + destGroupId.replace('.', '/') + "/" + destArtifactId + "/" + debianVersion + "/";
+        return artifactPath(destGroupId, destArtifactId, debianVersion);
+    }
+
+    /**
+     * Path to the files of an artifact relatively to the root of the repository.
+     */
+    private String artifactPath(String groupId, String artifactId, String version) {
+        return "/" + groupId.replace('.', '/') + "/" + artifactId + "/" + version + "/";
     }
 
     /**
@@ -425,18 +439,13 @@ public class SysInstallMojo extends AbstractMojo {
         return packagePath() + "/usr/share/maven-repo" + debianRepoPath();
     }
 
-    protected String pomName() {
+    /**
+     * Name of the pom file in the repository.
+     */
+    protected String pomName(String artifactId, String version) {
         return artifactId + "-" + version + ".pom";
     }
 
-    protected String destPomName() {
-        return destArtifactId + "-" + version + ".pom";
-    }
-
-    protected String debianPomName() {
-        return destArtifactId + "-" + debianVersion + ".pom";
-    }
-
     private String pomSrcPath() {
         return basedir.getAbsolutePath() + "/pom.xml";
     }
@@ -458,11 +467,11 @@ public class SysInstallMojo extends AbstractMojo {
     }
 
     private String pomDestPath() {
-        return fullRepoPath() + destPomName();
+        return fullRepoPath() + pomName(destArtifactId, version);
     }
 
     private String debianPomDestPath() {
-        return debianFullRepoPath() + debianPomName();
+        return debianFullRepoPath() + pomName(destArtifactId, debianVersion);
     }
 
     protected String jarName() {
@@ -603,7 +612,7 @@ public class SysInstallMojo extends AbstractMojo {
     protected void copyJar() throws IOException {
         File jarFile = new File(fullJarName());
         if (jarFile.exists()) {
-            System.out.println("Install jar file into Maven repo: " + jarFile.getAbsolutePath());
+            getLog().info("Install jar file into Maven repo: " + jarFile.getAbsolutePath());
             FileUtils.copyFile(jarFile, new File(jarDestPath()));
             if (debianVersion != null && !debianVersion.equals(version)) {
                 mkdir(debianFullRepoPath());
@@ -618,7 +627,7 @@ public class SysInstallMojo extends AbstractMojo {
     private void copyJarToUsj() throws IOException {
         File jarFile = new File(fullJarName());
         if (jarFile.exists()) {
-            System.out.println("Install jar for " + artifactId + " into /usr/share/java");
+            getLog().info("Install jar for " + artifactId + " into /usr/share/java");
             mkdir(compatSharePath());
             if (noUsjVersionless) {
                 FileUtils.copyFile(jarFile, new File(versionedFullCompatPath()));
@@ -715,6 +724,8 @@ public class SysInstallMojo extends AbstractMojo {
             // creation
             installToUsj = pomOption.isJavaLib() ||
                            (packageIsJavaLib && installToUsj);
+
+            relocatedArtifacts = pomOption.getRelocatedArtifacts();
         }
 
         List<String> params = new ArrayList<String>();
@@ -728,22 +739,22 @@ public class SysInstallMojo extends AbstractMojo {
         String mavenPublishedRulesPath = new File(debianDir, mavenPublishedRules).getAbsolutePath();
         params.add("--published-rules=" + mavenPublishedRulesPath);
 
-        System.out.println("Cleaning pom file: " + pomFile + " with options:");
-        System.out.println("\t--keep-pom-version --package=" + destPackage);
-        System.out.println("\t--rules=" + mavenRulesPath);
-        System.out.println("\t--ignore-rules=" + mavenIgnoreRulesPath);
-        System.out.println("\t--published-rules=" + mavenPublishedRulesPath);
+        getLog().info("Cleaning pom file: " + pomFile + " with options:");
+        getLog().info("\t--keep-pom-version --package=" + destPackage);
+        getLog().info("\t--rules=" + mavenRulesPath);
+        getLog().info("\t--ignore-rules=" + mavenIgnoreRulesPath);
+        getLog().info("\t--published-rules=" + mavenPublishedRulesPath);
 
         // add optional --no-parent option
         if (pomOption != null && pomOption.isNoParent()) {
             params.add("--no-parent");
-            System.out.println("\t--no-parent");
+            getLog().info("\t--no-parent");
         }
 
         // add options --keep-elements option
         if (pomOption != null && pomOption.getKeepElements() != null) {
             params.add("--keep-elements=" + pomOption.getKeepElements());
-            System.out.println("\t--keep-elements=" + pomOption.getKeepElements());
+            getLog().info("\t--keep-elements=" + pomOption.getKeepElements());
         }
 
         params.add(pomFile.getAbsolutePath());
@@ -783,6 +794,42 @@ public class SysInstallMojo extends AbstractMojo {
         }
     }
 
+    /**
+     * Install the relocated poms
+     */
+    protected void relocatePoms() throws IOException {
+        if (relocatedArtifacts != null) {
+            for (Dependency relocated : relocatedArtifacts) {
+                getLog().info("Relocating " + relocated.formatCompactNotation());
+
+                File relocatedPath = new File(packagePath() + "/usr/share/maven-repo" + artifactPath(relocated.getGroupId(), relocated.getArtifactId(), relocated.getVersion()));
+                File relocatedPom = new File(relocatedPath, pomName(relocated.getArtifactId(), relocated.getVersion()));
+                String pom = createRelocationPom(relocated);
+
+                FileUtils.copyStreamToFile(new RawInputStreamFacade(new ByteArrayInputStream(pom.getBytes("UTF-8"))), relocatedPom);
+            }
+        }
+    }
+
+    private String createRelocationPom(Dependency relocateArtifact) {
+        return "<project>\n" +
+                "  <modelVersion>4.0.0</modelVersion>\n" +
+                "  <groupId>" + relocateArtifact.getGroupId() + "</groupId>\n" +
+                "  <artifactId>" + relocateArtifact.getArtifactId() + "</artifactId>\n" +
+                "  <version>" + relocateArtifact.getVersion() + "</version>\n" +
+                "  <properties>\n" +
+                "    <debian.package>" + destPackage + "</debian.package>\n" +
+                "  </properties>\n" +
+                "  <distributionManagement>\n" +
+                "    <relocation>\n" +
+                "      <groupId>" + destGroupId + "</groupId>\n" +
+                "      <artifactId>" + destArtifactId + "</artifactId>\n" +
+                "      <version>" + debianVersion + "</version>\n" +
+                "    </relocation>\n" +
+                "  </distributionManagement>\n" +
+                "</project>";
+    }
+
     /**
      * Prepare the destination  directories: remove the directory symlinks that were created
      * by copy-repo.sh if they exist as they point to a directory owned by root and that cannot
@@ -801,6 +848,7 @@ public class SysInstallMojo extends AbstractMojo {
         cleanPom();
         prepareDestDirs();
         copyPom();
+        relocatePoms();
         if (installToUsj) {
             copyJarToUsj();
             symlinkJar();
