@@ -126,7 +126,11 @@ sub clean {
 	# don't populate the directory just to run a clean target.
 	if (-e "$this->{cwd}/debian/maven-repo")
 	{
-		$this->doit_in_builddir_noerror(@{$this->{maven_cmd}}, "clean");
+	        if (!@_) {
+        	        push(@_, "clean");
+        	}
+
+		$this->doit_in_builddir_noerror(@{$this->{maven_cmd}}, @_);
 		doit("rm", "-r", "$this->{cwd}/debian/maven-repo");
 	}
 	$this->doit_in_builddir('for dir in $(find . -name target -type d); do if [ -f $(echo $dir | sed -e s/target$/pom.xml/) ]; then rm -Rf $dir; fi done');
